core-input

This is an example of a single-line text input. See console for committed values.
This is an example of a single-line password input. See console for committed values.
This is an example of a single-line text input with number validation. See console for validation errors.
This is an example of a multi-line text input with 3 rows. The input is normally unstyled but here is styled with a dotted border to show its size.
This is an example of a multi-line text input sized with CSS. The input is normally unstyled but here is styled with a dotted border to show its size.